package dao.hsqldb;

import java.sql.Connection;
import java.sql.DriverManager;

import dao.DAOFactory;
import dao.DefinizioniDAO;


public class HsqldbDAOFactory extends DAOFactory {

	/**
	 * Driver JDBC per il database
	 */
	public static final String DRIVER = "org.hsqldb.jdbcDriver";

	/**
	 * URI del database
	 */
	public static final String DBURL = "jdbc:hsqldb:hsql://localhost/techwebDB";

	// --------------------------------------------

	// carica in memoria la classe del db
	static {
		try {
			Class.forName(DRIVER);
		} catch (Exception e) {
			System.err
					.println("HsqldbDAOFactory: failed to load HSQLDB JDBC driver"
							+ "\n" + e.toString());
			e.printStackTrace();
		}
	}

	// --------------------------------------------

	/**
	 * Crea una nuova connessione ad ogni richiesta. Normalmente si farebbe del pooling.
	 */
	public static Connection createConnection() {
		try {
			return DriverManager.getConnection(DBURL);
		} catch (Exception e) {
			System.err.println(HsqldbDAOFactory.class.getName()
					+ ".createConnection(): failed creating connection" + "\n"
					+ e.toString());
			e.printStackTrace();
			System.err
					.println("Was the database started? Is the database URL right?");
			return null;
		}
	}

	/**
	 * Chiude la connessione
	 */
	public static void closeConnection(Connection conn) {
		try {
			conn.close();
		} catch (Exception e) {
			System.err.println(HsqldbDAOFactory.class.getName()
					+ ".closeConnection(): failed closing connection" + "\n"
					+ e.toString());
			e.printStackTrace();
		}
	}

	// --------------------------------------------



	@Override
	public DefinizioniDAO getDefinizioniDAO() {
		return new HsqldbDefinizioniDAO();
	}

}
