package dao.hsqldb;


import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Statement;
import java.util.ArrayList;

import dao.DefinizioniDAO;
import dao.DefinizioniDTO;

public class HsqldbDefinizioniDAO implements DefinizioniDAO {

	//costanti letterali che wrappano le costanti del db
	
	static final String TABLE = "definizioni";

	static final String NOME = "Nome";
	static final String DEFINIZIONE = "Definizione";

	static final String insert = "INSERT " + "INTO " + TABLE + " ( " + NOME
			+ ", " + DEFINIZIONE + " " + ") " + "VALUES (?,?) ";

	static String read_by_nome = "SELECT * " + "FROM " + TABLE + " " + "WHERE "
			+ NOME + " = ? ";

	static String read_all = "SELECT * " + "FROM " + TABLE;

	static String create = "CREATE " + "TABLE " + TABLE + " ( " + NOME
			+ " VARCHAR(50) NOT NULL, " + DEFINIZIONE
			+ " VARCHAR(50) NOT NULL, " + "UNIQUE( " + NOME + " ) " + ") ";
	
	static String drop = "DROP " + "TABLE " + TABLE + " ";


	//inserisce una definizione nel db
	@Override
	public boolean create(DefinizioniDTO t) {

		boolean result = false;

		if (t == null) {
			return result;
		}
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			PreparedStatement prep_stmt = conn.prepareStatement(insert);
			prep_stmt.clearParameters();
			prep_stmt.setString(1, t.getNome());
			prep_stmt.setString(2, t.getDefinizione());
			prep_stmt.executeUpdate();

			prep_stmt.close();
			result = true;
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			HsqldbDAOFactory.closeConnection(conn);
		}
		return result;
	}

	//crea la tabella
	@Override
	public boolean createTable() {

		boolean result = false;
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			Statement stmt = conn.createStatement();
			stmt.execute(create);
			result = true;
			stmt.close();
		} catch (Exception e) {
		} finally {
			HsqldbDAOFactory.closeConnection(conn);
		}
		return result;
	}

	//droppa la tabella
	@Override
	public boolean dropTable() {
		boolean result = false;
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			Statement stmt = conn.createStatement();
			stmt.execute(drop);
			result = true;
			stmt.close();
		} catch (Exception e) {
		} finally {
			HsqldbDAOFactory.closeConnection(conn);
		}
		return result;
	}

	//restituisce tutte le definizioni contenute nella tabella
	@Override
	public DefinizioniDTO[] findAll() {
		ArrayList<DefinizioniDTO> result = new ArrayList<DefinizioniDTO>();
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			Statement stmt = conn.createStatement();

			ResultSet rs = stmt.executeQuery(read_all);
			while (rs.next()) {
				DefinizioniDTO entry = new DefinizioniDTO();
				entry.setNome(rs.getString(NOME));
				entry.setDefinizione(rs.getString(DEFINIZIONE));
				result.add(entry);
			}
			rs.close();
			stmt.close();
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			HsqldbDAOFactory.closeConnection(conn);
		}
		//crea un array statico della stessa dimensione dell'arraylist
		DefinizioniDTO[] ret = new DefinizioniDTO[result.size()];
		//converte l'arraylist in array
		ret = result.toArray(ret);
		return ret;
	}

	//cerca una definizione dato il nome se non  presente restituisce null
	@Override
	public DefinizioniDTO find(String nome) {
		DefinizioniDTO result = null;
		Connection conn = HsqldbDAOFactory.createConnection();
		try {
			PreparedStatement prep_stmt = conn.prepareStatement(read_by_nome);
			prep_stmt.clearParameters();
			prep_stmt.setString(1, nome);
			ResultSet rs = prep_stmt.executeQuery();
			if (rs.next()) {
				DefinizioniDTO entry = new DefinizioniDTO();
				entry.setNome(rs.getString(NOME));
				entry.setDefinizione(rs.getString(DEFINIZIONE));
				result = entry;
			}
			rs.close();
			prep_stmt.close();
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			HsqldbDAOFactory.closeConnection(conn);
		}
		return result;
	}

}
