import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintWriter;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import dao.DAOFactory;
import dao.DefinizioniDAO;
import dao.DefinizioniDTO;


public class ModificaDefinizione extends HttpServlet {
	private static final long serialVersionUID = 1L;

	/**
	 * variabile di satto contenente il DAO per accedere al db viene
	 * inizializzata all'atto della creazione della servlet
	 */
	private DefinizioniDAO definizioniDao;

	@Override
	public void init(ServletConfig config) throws ServletException {
		super.init(config);
		String factory = getServletContext().getInitParameter("daoFactory");
		definizioniDao = DAOFactory.getDAOFactory(factory).getDefinizioniDAO();
	}

	// Serve sia le GET che le POST
	@Override
	protected void service(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {
		String nome = request.getParameter("nome");
		String definizione = request.getParameter("definizione");
		PrintWriter out = response.getWriter();

		// nome e definizione presenti come parametri
		// casi n 1 e 4 della descrizine
		// dell'esercizio
		if (nome != null && !nome.isEmpty() && definizione != null
				&& !definizione.isEmpty()) {
			if (definizioniDao.find(nome) != null) {
				// definizione gi esistente (caso 1)
				throw new ServletException(
						"Non  possibile sostituire una definizione esistente");
			} else {
				// effettua l'inserimento nel db e visualizza la pagina di
				// conferma (caso 4)
				DefinizioniDTO def = new DefinizioniDTO();
				def.setNome(nome);
				def.setDefinizione(definizione);
				if (!definizioniDao.create(def)) {
					// errore nell'inserimento
					throw new ServletException("Errore nell'inserimento");
				}
				printHeader(out, "Inserimento Avvenuto");
				out.println("<h1>Definizione inserita:</h1>");
				out
						.println("<table><tr><th>Nome</th><th>Definizione</th></tr>");
				out.println("<tr><td>" + def.getNome() + "</td><td>"
						+ def.getDefinizione() + "</td></tr></table>");
				out
						.println("<p><a href=\"modificaDefinizione\">Inserisci una nuova parola</a></p>");
				out.println("</body></html>");

			}
		} else {// casi 2 e 3 visualizza la form in ogni modo
			String titolo;
			// il nome o non  stato passato o non si trova nel dizionario
			// setta il titolo opportuno
			if (nome == null || nome.isEmpty()
					|| definizioniDao.find(nome) == null) {
				titolo = "Inserimento nuova parola";
			} else {// il nome  presente nel dizionario
				titolo = "Modifica di una parola esistente";

				// recupera la definizione dal db
				DefinizioniDTO entry = definizioniDao.find(nome);
				if (entry != null) {
					definizione = entry.getDefinizione();
				}
			}

			// stampa la pagina html
			printHeader(out, titolo);
			out.println("<h1>Dati richiesti:</h1>");
			out
					.println("<form method=\"POST\"><table><tr><th>Nome:</th><td><input type=\"text\" name=\"nome\" value=\""
							+ (nome != null ? nome : "") + "\"/></td></tr>");
			out
					.println("<tr><th>Definizione:</th><td><input type=\"text\" name=\"definizione\" value=\""
							+ (definizione != null ? definizione : "")
							+ "\"/></td></tr>");
			out
					.println("<tr><td colspan=\"2\" style=\"text-align: center;\"><input type=\"submit\" value=\"Inserisci\" /></td></tr>");
			out.println("</table></form>");
			out.println("</body></html>");
		}

	}

	// funzione che stampa l'intera parte di header html con titolo custom
	private void printHeader(PrintWriter pw, String titolo) {
		pw
				.println("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">"
						+ "<html>"
						+ "<head>"
						+ "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">"
						+ "<title>"
						+ titolo
						+ "</title>"
						+ "<link rel=\"stylesheet\" href=\"styles/default.css\" type=\"text/css\">"
						+ "</head>");
	}
}
